%define		devel %mklibname %{name} -d

%global		__requires_exclude ^/bin/ksh$

# Use fewer cores on ix86
%ifarch %{ix86}
%global		_smp_ncpus_max 1
%endif

Name:		ecflow
Version:	5.13.4
Release:	%mkrel 1
Summary:	ecFlow is a work flow package
Group:		Monitoring
License:	ASL 2.0
URL:		https://confluence.ecmwf.int//display/ECFLOW
Source0:	https://confluence.ecmwf.int/download/attachments/8650755/ecFlow-%{version}-Source.tar.gz?api=v2#/%{name}-%{version}.tar.gz
Source1:	https://confluence.ecmwf.int/download/attachments/13207146/2017-01-19-ecFlowUI-for-ecFlow-training-course.pdf
Source2:	https://confluence.ecmwf.int/download/attachments/13207146/ecflowcourse2018.pdf#/ecflowcourse-20180122.pdf
Source3:	https://confluence.ecmwf.int/download/attachments/13207146/ecflowcourse2018_python.pdf#/ecflowcourse-20180122_python.pdf

Patch0:		ecflow-4.8.0-set-ecf-home.patch
# Patches from Debian
Patch1:		0001-perl-interpeter.patch
# Mageia patches

BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	boost-devel
BuildRequires:	boost-devel-static
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	libicu-devel
BuildRequires:	libstdc++-devel
BuildRequires:	m4
BuildRequires:	libgcrypt-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-numpy-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(Qt6Core)
BuildRequires:	pkgconfig(Qt6Charts)
BuildRequires:	pkgconfig(Qt6Gui)
BuildRequires:	pkgconfig(Qt6Network)
BuildRequires:	pkgconfig(Qt6Svg)
BuildRequires:	pkgconfig(Qt6Widgets)
BuildRequires:	pkgconfig(xpm)
BuildRequires:	pkgconfig(gl)
BuildRequires:	pkgconfig(libpng16)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(graphite2)
BuildRequires:	pkgconfig(xau)
BuildRequires:	pkgconfig(xcb)
BuildRequires:	git-core
BuildRequires:	pkgconfig(Qt6Core5Compat)

Requires:	pdksh
Requires:	git

%description
ecFlow is a work flow package that enables users to run a large number of
programs (with dependencies on each other and on time) in a controlled
environment. It provides reasonable tolerance for hardware and software
failures, combined with good restart capabilities.

ecFlow submits tasks (jobs) and receives acknowledgements from tasks when
they change status and when they send events, using child commands embedded
in the scripts. Ecflow stores the relationship between tasks, and is able to
submit tasks dependent on triggers.

%package -n	python3-%{name}
Summary:	Python 3 bindings for ecFlow
Requires:	%{name}-ui
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
ecFlow is a meteorological work flow package that enables
users to run a large number of programs ( with dependencies
on each other and on time) in a controlled environment.

This package contains Python3 modules used in writing ecflow scripts.

%package -n	%{name}-ui
Summary:	Graphical applications for ecFlow
Requires:	python3-%{name} = %{version}-%{release}
Requires(pre):	pdksh

%description -n	%{name}-ui
ecFlow is a work flow package that enables users to run a large number of
programs (with dependencies on each other and on time) in a controlled
environment. It provides reasonable tolerance for hardware and software
failures, combined with good restart capabilities.

ecFlow submits tasks (jobs) and receives acknowledgements from tasks when
they change status and when they send events, using child commands embedded
in the scripts. Ecflow stores the relationship between tasks, and is able to
submit tasks dependent on triggers.

This package contains the client tools.

%package -n	%{name}-server
Summary:	The ecFlow server
Provides:	%{name} = %{version}-%{release}
Requires:	%{name}-ui = %{version}-%{release}
Requires(pre):	pdksh

%description -n	%{name}-server
ecFlow is a work flow package that enables users to run a large number of
programs (with dependencies on each other and on time) in a controlled
environment. It provides reasonable tolerance for hardware and software
failures, combined with good restart capabilities.

ecFlow submits tasks (jobs) and receives acknowledgements from tasks when
they change status and when they send events, using child commands embedded
in the scripts. Ecflow stores the relationship between tasks, and is able to
submit tasks dependent on triggers.

%package -n	%{devel}
Summary:	The cmake files for ecFlow
Requires:	%{name}-ui = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devel}
The cmake development files for ecFlow

%prep
%autosetup -p1 -n ecFlow-%{version}-Source

# Copy the documentation
cp %{SOURCE1} .
cp %{SOURCE2} .
cp %{SOURCE3} .

%py3_shebang_fix tools/ecflow_fuse.py

# There is a looping symlink in version 5.2.1. Remove to be safe.
rm -f cereal/cereal

%build
%cmake_qt6 -GNinja \
	-DENABLE_STATIC_BOOST_LIBS=OFF \
	-DENABLE_SSL=ON \
	-DENABLE_UI_USAGE_LOG=OFF \
	-DENABLE_SECURE_USER=OFF \
	-DENABLE_PYTHON_PTR_REGISTER=ON \
	-DBOOST_ROOT=%{_prefix} \
	-DECFLOW_QT6=ON \
	-DENABLE_GUI=OFF \
	-DPYTHON_EXECUTABLE=%{python3} \
	-DPYTHON_MIN_VERSION=%{python3_version} \
	-DBoost_PYTHON_LIBRARY_RELEASE=%{_libdir}/libboost_python%{python3_pkgversion}.so \
	-DDISABLE_OS_CHECK=ON \
	-Decflow_FULL_INSTALL_CMAKE_DIR=%{_libdir}/cmake/%{name} \
	-Decflow_FULL_INSTALL_LIB_DIR=%{_libdir}
%cmake_build

%install
%cmake_install

install -Dpm 644 ./libs/server/server_environment.cfg %{buildroot}%{_var}/%{name}/server_environment.cfg

%files -n	%{name}-ui
%doc README.rst *.pdf
%{_bindir}/ecflow_client
%{_bindir}/ecflow_standalone
%{_bindir}/ecflow_ui
%{_bindir}/ecflow_ui.x
%{_bindir}/ecflow_udp_client
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/etc/

%files -n       python3-%{name}
%doc README.rst
%{_bindir}/ecflow_fuse.py
%{python3_sitelib}/%{name}/

%files -n	%{name}-server
%doc README.rst
%{_bindir}/%{name}_*.pl
%{_bindir}/*.sh
%{_bindir}/ecflow_server
%{_bindir}/ecflow_http
%{_bindir}/ecflow_udp
%{_var}/%{name}/

%files -n	%{devel}
%{_libdir}/cmake/%{name}/


%changelog
* Fri Sep 13 2024 wally <wally> 5.13.4-1.mga10
+ Revision: 2095687
- new version 5.13.4
- rebuild for boost 1.86.0

* Mon Aug 19 2024 kekepower <kekepower> 5.13.3-1.mga10
+ Revision: 2087043
- Update to version 5.13.3

* Sun Jun 23 2024 wally <wally> 5.13.0-1.mga10
+ Revision: 2076290
- new version 5.13.0
- rebuild for boost 1.85.0

* Sat Jan 13 2024 wally <wally> 5.11.4-2.mga10
+ Revision: 2030784
- add patch to fix missing #include
- drop old obsoletes and conflicts
- rebuild for boost 1.84.0

* Fri Oct 20 2023 kekepower <kekepower> 5.11.4-1.mga10
+ Revision: 1999874
- Update to version 5.11.4

* Fri Sep 29 2023 kekepower <kekepower> 5.11.3-1.mga10
+ Revision: 1992083
- Update to version 5.11.3

* Wed Sep 27 2023 wally <wally> 5.9.2-4.mga10
+ Revision: 1991430
- rebuild for boost 1.83.0

* Wed Jan 04 2023 kekepower <kekepower> 5.9.2-3.mga9
+ Revision: 1929938
- Rebuild with Qt6

* Sat Dec 24 2022 wally <wally> 5.9.2-2.mga9
+ Revision: 1926463
- rebuild for boost 1.81.0

* Mon Dec 05 2022 kekepower <kekepower> 5.9.2-1.mga9
+ Revision: 1918225
- Update to version 5.9.2
- Remove old Obsoletes

* Sun Nov 13 2022 kekepower <kekepower> 5.9.1-2.mga9
+ Revision: 1906777
- Bump rel after failed build
- Update to version 5.9.1

* Sat Oct 08 2022 kekepower <kekepower> 5.9.0-1.mga9
+ Revision: 1895550
- Update to version 5.9.0

* Tue Aug 09 2022 kekepower <kekepower> 5.8.4-1.mga9
+ Revision: 1876445
- Add patch to include ctime in ACore/src/Passwd.cpp
- Update to version 5.8.4
+ wally <wally>
- rebuild for boost 1.79.0

* Wed Mar 16 2022 kekepower <kekepower> 5.8.3-1.mga9
+ Revision: 1794901
- Update to version 5.8.3

* Sun Feb 27 2022 kekepower <kekepower> 5.8.1-1.mga9
+ Revision: 1786377
- Update to version 5.8.1

* Tue Feb 22 2022 tv <tv> 5.7.2-3.mga9
+ Revision: 1782827
- Rebuild for python-3.10

* Sun Dec 19 2021 wally <wally> 5.7.2-2.mga9
+ Revision: 1762637
- rebuild for boost 1.78.0

* Tue Dec 14 2021 kekepower <kekepower> 5.7.2-1.mga9
+ Revision: 1762054
- Remove Patch50: ecflow-include-vector.patch
- Fix source URL's
- Reupload correct source tar ball
- Update to version 5.7.2

* Thu Sep 09 2021 wally <wally> 5.7.0-2.mga9
+ Revision: 1744709
- rebuild for boost 1.77.0

* Sun May 30 2021 kekepower <kekepower> 5.7.0-1.mga9
+ Revision: 1728841
- Update to version 5.7.0

* Fri May 14 2021 wally <wally> 5.6.0-6.mga9
+ Revision: 1723066
- add patch to fix missing include
- rebuild for boost 1.76.0

* Sat Mar 27 2021 tv <tv> 5.6.0-5.mga9
+ Revision: 1710862
- rebuild for python 3.9

* Thu Dec 31 2020 wally <wally> 5.6.0-4.mga8
+ Revision: 1666749
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 5.6.0-3.mga8
+ Revision: 1661991
- rebuild for boost 1.74.0

* Wed Dec 16 2020 umeabot <umeabot> 5.6.0-2.mga8
+ Revision: 1658337
- Rebuild for new Qt5

* Tue Dec 08 2020 kekepower <kekepower> 5.6.0-1.mga8
+ Revision: 1654513
- Update to version 5.6.0

* Thu Nov 12 2020 kekepower <kekepower> 5.5.3-2.mga8
+ Revision: 1644884
- Update to version 5.5.3

* Tue Jul 21 2020 wally <wally> 5.5.1-2.mga8
+ Revision: 1607623
- build with new cmake macros

* Wed Jul 15 2020 kekepower <kekepower> 5.5.1-1.mga8
+ Revision: 1606176
- Update to version 5.5.1

* Mon Jul 06 2020 kekepower <kekepower> 5.5.0-1.mga8
+ Revision: 1602532
- Update to version 5.5.0

* Sun May 10 2020 kekepower <kekepower> 5.4.0-1.mga8
+ Revision: 1582565
- Add patch to fix build error with gcc 10
- Update to version 5.4.0

* Sun May 03 2020 wally <wally> 5.3.1-2.mga8
+ Revision: 1578045
- rebuild for boost 1.73.0

* Thu Apr 09 2020 kekepower <kekepower> 5.3.1-1.mga8
+ Revision: 1565683
- Update to version 5.3.1

* Sat Mar 07 2020 kekepower <kekepower> 5.3.0-1.mga8
+ Revision: 1554723
- Update to version 5.3.0

* Thu Feb 20 2020 umeabot <umeabot> 5.2.3-2.mga8
+ Revision: 1546794
- Mageia 8 Mass Rebuild

* Wed Feb 19 2020 kekepower <kekepower> 5.2.3-1.mga8
+ Revision: 1544808
- Update to version 5.2.3

* Tue Feb 04 2020 kekepower <kekepower> 5.2.1-1.mga8
+ Revision: 1486876
- Use 1 core to build on ix86
- Update to version 5.2.1

* Mon Jan 27 2020 kekepower <kekepower> 5.1.0-2.mga8
+ Revision: 1483823
- Fix python3 shebang
- Use %%ninja_* macros instead of meson
- Use %%meson_build and %%meson_install
+ wally <wally>
- rebuild for boost 1.72.0

* Fri Oct 04 2019 kekepower <kekepower> 5.1.0-1.mga8
+ Revision: 1449269
- Update to version 5.1.0

* Mon Sep 09 2019 wally <wally> 4.16.0-2.mga8
+ Revision: 1439055
- rebuild for python3.8
- drop python2 support

* Thu Aug 15 2019 kekepower <kekepower> 4.16.0-1.mga8
+ Revision: 1429388
- Update to version 4.16.0

* Sun Jun 30 2019 kekepower <kekepower> 4.15.0-1.mga8
+ Revision: 1416206
- Update to version 4.15.0

* Sat Mar 30 2019 kekepower <kekepower> 4.14.0-1.mga7
+ Revision: 1381773
- Update to version 4.14.0

* Sat Mar 30 2019 umeabot <umeabot> 4.13.0-2.mga7
+ Revision: 1381623
- Qt5 Rebuild

* Fri Feb 22 2019 kekepower <kekepower> 4.13.0-1.mga7
+ Revision: 1369357
- Update to version 4.13.0

* Mon Feb 11 2019 kekepower <kekepower> 4.12.0-1.mga7
+ Revision: 1365367
- Update to version 4.12.0

* Mon Jan 07 2019 kekepower <kekepower> 4.11.1-2.mga7
+ Revision: 1351019
- Rebuild for Python 3.7

* Tue Oct 23 2018 kekepower <kekepower> 4.11.1-1.mga7
+ Revision: 1324601
- Update to version 4.11.1

* Tue Oct 16 2018 kekepower <kekepower> 4.11.0-1.mga7
+ Revision: 1321173
- Update to version 4.11.0
- Rediffed patches
- Removed merged patch
+ wally <wally>
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 4.10.0-2.mga7
+ Revision: 1297558
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 wally <wally> 4.10.0-1.mga7
+ Revision: 1250773
- add Debian patches to fix build
- use mga compiler flags
+ kekepower <kekepower>
- Update to version 4.10.0

* Sun Apr 15 2018 daviddavid <daviddavid> 4.9.0-3.mga7
+ Revision: 1218925
- fix bogus requires on /bin/ksh
- fix owner of data dir
+ kekepower <kekepower>
- Use python_provde
- Fix Summary for python

* Thu Apr 05 2018 kekepower <kekepower> 4.9.0-1.mga7
+ Revision: 1215473
- Disable patch1
- BR git
- Update to version 4.9.0
- Rediffed a few patches and removed unnecessary patches

* Sat Feb 24 2018 kekepower <kekepower> 4.8.0-10.mga7
+ Revision: 1204747
- ecflow-python was renamed, use Conflicts instead of Obsoletes

* Fri Feb 23 2018 kekepower <kekepower> 4.8.0-9.mga7
+ Revision: 1204317
- Renamed ecflow-python to python2-ecflow
- Enabled python3-ecflow
- Added more patches from Debian

* Wed Feb 21 2018 kekepower <kekepower> 4.8.0-8.mga7
+ Revision: 1203987
- Added patches from Debian to enable building with GCC

* Fri Feb 16 2018 kekepower <kekepower> 4.8.0-7.mga7
+ Revision: 1201773
- One last Conflicts change

* Thu Feb 15 2018 kekepower <kekepower> 4.8.0-6.mga7
+ Revision: 1201617
- Switched Obsoletes with Conflicts
- Fixed the %%files section a bit

* Wed Feb 14 2018 kekepower <kekepower> 4.8.0-5.mga7
+ Revision: 1200990
- Disabled the Motif binary, library and config files
- Enabled SSL
- Moved some files around to where they really belong

* Mon Feb 12 2018 kekepower <kekepower> 4.8.0-4.mga7
+ Revision: 1200650
- Renamed PDF docs with complete date
- Fixed a typo, readme->README
- Added PDF documentation
- Added patch to set ECF_HOME
- Create /var/ecflow
- Server requires ui
- General cleanup

* Wed Feb 07 2018 kekepower <kekepower> 4.8.0-3.mga7
+ Revision: 1199540
- Bump release
- Disable clang sanitizer
- Removed BR for compiler-rt
- Removed my debug lines at the bottom
- Add compiler-rt to BR
- Enable -fPIC on arm
- Remove unused export lines

* Wed Feb 07 2018 kekepower <kekepower> 4.8.0-1.mga7
+ Revision: 1199526
- Added Monitoring group
- A separate package for the library
- Fixed compilation issues
- imported package ecflow

